==> beast-0.5.1.tar.gz: beast-0.5.1/beast-gtk/bstgentypes.h <==

/* Generated data (by glib-mkenums) */


/* --- bstmarker.h --- */
#define BST_TYPE_MARKER_TYPE	    (bst__type_id__BstMarkerType)
extern GType bst__type_id__BstMarkerType;

/* --- bstmenus.h --- */
#define BST_TYPE_CHOICE_FLAGS	    (bst__type_id__BstChoiceFlags)
extern GType bst__type_id__BstChoiceFlags;

/* --- bstqsampler.h --- */
#define BST_TYPE_QSAMPLER_TYPE	    (bst__type_id__BstQSamplerType)
extern GType bst__type_id__BstQSamplerType;
#define BST_TYPE_QSAMPLER_DRAW_MODE	    (bst__type_id__BstQSamplerDrawMode)
extern GType bst__type_id__BstQSamplerDrawMode;

/* --- bstradiotools.h --- */
#define BST_TYPE_RADIO_TOOLS_FLAGS	    (bst__type_id__BstRadioToolsFlags)
extern GType bst__type_id__BstRadioToolsFlags;

/* --- bstdefs.h --- */
#define BST_TYPE_OPS	    (bst__type_id__BstOps)
extern GType bst__type_id__BstOps;
#define BST_TYPE_QUANTIZATION_TYPE	    (bst__type_id__BstQuantizationType)
extern GType bst__type_id__BstQuantizationType;

/* Generated data ends here */


/*-------- begin ../sfi/sfidl generated code --------*/



typedef struct _BstGConfig BstGConfig;

struct _BstGConfig {
  gchar* rc_version;
  SfiBool snet_anti_aliased;
  SfiBool snet_edit_fallback;
  SfiBool snet_swap_io_channels;
  SfiInt tab_width;
};

BstGConfig* bst_gconfig_new (void);
BstGConfig* bst_gconfig_copy_shallow (BstGConfig* rec);
BstGConfig* bst_gconfig_from_rec (SfiRec *sfi_rec);
SfiRec *bst_gconfig_to_rec (BstGConfig* rec);
void bst_gconfig_free (BstGConfig* rec);


extern SfiRecFields bst_gconfig_fields;



/*-------- end ../sfi/sfidl generated code --------*/

==> beast-0.5.4-rc1.tar.gz: beast-0.5.4-rc1/beast-gtk/bstgentypes.h <==

/* Generated data (by glib-mkenums) */


/* --- bstfiledialog.h --- */
#define BST_TYPE_FILE_DIALOG_MODE	    (bst__type_id__BstFileDialogMode)
extern GType bst__type_id__BstFileDialogMode;

/* --- bstmarker.h --- */
#define BST_TYPE_MARKER_TYPE	    (bst__type_id__BstMarkerType)
extern GType bst__type_id__BstMarkerType;

/* --- bstmenus.h --- */
#define BST_TYPE_CHOICE_FLAGS	    (bst__type_id__BstChoiceFlags)
extern GType bst__type_id__BstChoiceFlags;

/* --- bstqsampler.h --- */
#define BST_TYPE_QSAMPLER_TYPE	    (bst__type_id__BstQSamplerType)
extern GType bst__type_id__BstQSamplerType;
#define BST_TYPE_QSAMPLER_DRAW_MODE	    (bst__type_id__BstQSamplerDrawMode)
extern GType bst__type_id__BstQSamplerDrawMode;

/* --- bstradiotools.h --- */
#define BST_TYPE_RADIO_TOOLS_FLAGS	    (bst__type_id__BstRadioToolsFlags)
extern GType bst__type_id__BstRadioToolsFlags;

/* --- bstdefs.h --- */
#define BST_TYPE_ACTION_REGIONS	    (bst__type_id__BstActionRegions)
extern GType bst__type_id__BstActionRegions;
#define BST_TYPE_QUANTIZATION_TYPE	    (bst__type_id__BstQuantizationType)
extern GType bst__type_id__BstQuantizationType;

/* Generated data ends here */


/*-------- begin ../sfi/sfidl generated code --------*/



typedef struct _BstGConfig BstGConfig;

struct _BstGConfig {
  gchar* rc_version;
  SfiBool snet_anti_aliased;
  SfiBool snet_edit_fallback;
  SfiBool snet_swap_io_channels;
  SfiInt tab_width;
};

BstGConfig* bst_gconfig_new (void);
BstGConfig* bst_gconfig_copy_shallow (BstGConfig* rec);
BstGConfig* bst_gconfig_from_rec (SfiRec *sfi_rec);
SfiRec *bst_gconfig_to_rec (BstGConfig* rec);
void bst_gconfig_free (BstGConfig* rec);


extern SfiRecFields bst_gconfig_fields;



/*-------- end ../sfi/sfidl generated code --------*/
